@@ -13,7 +13,7 @@ from fileinit import fileinit
 pre_comment_shell = ["init"]
 
 # 進捗表示関数
-def show_progress(job_pool):
+def show_progress(job_pool, slave_debug):
 	all_n = len(job_pool)	# 全ジョブ数
 	done_n = job_pool.count(status = "done")	# 指定ステータスのジョブの数をカウントする
 	doing_idx_ls = job_pool.get_all_idx(status = "doing")	# 指定ステータスのジョブ(index)をすべて取得
@@ -21,19 +21,21 @@ def show_progress(job_pool):
 	show_str = "[mult] running jobs [done: %d/%d, doing: %s]..."%(done_n, all_n, doing_str) + " "*5
 	# 前回とコメントの違いがない場合はスキップ
 	if show_str == pre_comment_shell[0]: return None
-	print(show_str, end = "\r")
+	end_s = ("\n" if slave_debug else "\r")
+	print(show_str, end = end_s)
 	pre_comment_shell[0] = show_str
 
 # popenをたたく際のデフォルト処理 (単に「python」コマンドを使う)
-def default_popen_call_func(slave_filename, job_id):
+def default_popen_call_func(slave_filename, job_id, slave_debug):
 	# ディレクトリ名を取り除いたファイル名を取得
 	slave_basename = os.path.basename(slave_filename)
+	# 標準・エラー出力の扱い
+	std_args = ({} if slave_debug else {"stdout": subprocess.PIPE, "stderr": subprocess.PIPE})
 	# 子プロセスを叩く
 	subprocess.Popen(
 		["python", slave_basename, job_id],
 		cwd = slave_filename+"/../",	# slaveファイルが存在するディレクトリ
-		stdout = subprocess.PIPE,
-		stderr = subprocess.PIPE
+		**std_args	# 標準・エラー出力の扱い
 	)
 
 # 16進数の記号
@@ -108,7 +110,7 @@ def choose_one(arg_ls, arg_order):
 	raise Exception("[error] arg_orderの指定が不正です")
 
 # ジョブの投入
-def throw_job(job, data_dir, slave_filename, popen_call_func):
+def throw_job(job, data_dir, slave_filename, popen_call_func, slave_debug):
 	# ジョブ識別記号
 	job_id = job["job_id"]
 	# 入力オブジェクト
@@ -119,7 +121,7 @@ def throw_job(job, data_dir, slave_filename, popen_call_func):
 	with open(input_filename, "wb") as f:
 		pickle.dump(input_obj, f)
 	# popenをたたく処理
-	popen_call_func(slave_filename, job_id)
+	popen_call_func(slave_filename, job_id, slave_debug)
 
 # 指定したジョブが完了していれば結果を返す (未完了の場合はNoneを返す)
 def get_job_result(job_id, data_dir):
@@ -144,7 +146,8 @@ def call(
 	n,	# 並列数
 	job_order = "ordered",	# ジョブ実行順序 (random, ordered)
 	progress = False,	# 進捗表示
-	popen_call_func = None	# popenをたたく際のカスタム処理 (デフォルトのNone指定で単に「python」コマンドを使う; 引数はslave_filenameおよびjob_idx)
+	popen_call_func = None,	# popenをたたく際のカスタム処理 (デフォルトのNone指定で単に「python」コマンドを使う; 引数はslave_filename, job_idx, slave_debug)
+	slave_debug = False	# スレーブの標準出力の表示 (debug)
 ):
 	# デフォルトのpopenの場合
 	if popen_call_func is None:
@@ -154,7 +157,7 @@ def call(
 	# ジョブ識別記号
 	jid_prefix = gen_random_prefix(n = 16)	# ランダムな接頭辞の生成 (ジョブ識別記号に用いる)
 	# ジョブ投入を部分適用 (引数が多くてわかりにくいため)
-	throw_job_partial = lambda job: throw_job(job, data_dir, slave_filename, popen_call_func)	# ジョブの投入
+	throw_job_partial = lambda job: throw_job(job, data_dir, slave_filename, popen_call_func, slave_debug)	# ジョブの投入
 	# jobを列挙
 	job_pool = JobPool()	# ジョブ管理
 	for idx, input_obj in enumerate(input_ls):
@@ -164,7 +167,7 @@ def call(
 	output_ls = [None for _ in input_ls]
 	while True:
 		# 進捗表示
-		if progress is True: show_progress(job_pool)	# 進捗表示関数
+		if progress is True: show_progress(job_pool, slave_debug)	# 進捗表示関数
 		# 完了判定
 		done_n = job_pool.count(status = "done")	# 指定ステータスのジョブの数をカウントする
 		if done_n == len(job_pool): break	# すべてdoneの場合
